@@ -11,15 +11,14 @@ from cachetools import TTLCache
 from ddtrace.trace import tracer
 from discord.ext.commands import AutoShardedBot, CommandError, CommandNotFound, Context
 
+from . import spelltable, tablestream
 from .database import db_session_manager, initialize_connection
 from .enums import GameService
 from .metrics import setup_ignored_errors, setup_metrics
 from .models import GameLinkDetails
 from .operations import safe_delete_message
-from .services import ChannelsService, GamesService, GuildsService, VerifiesService
+from .services import ServicesRegistry
 from .settings import settings
-from .spelltable import generate_spelltable_link
-from .tablestream import generate_tablestream_link
 from .utils import user_can_moderate
 
 if TYPE_CHECKING:
@@ -30,6 +29,10 @@ if TYPE_CHECKING:
 
 logger = logging.getLogger(__name__)
 
+# Disable pointless nacl warning log coming from discord.py.
+if hasattr(discord.VoiceClient, "warn_nacl"):  # pragma: no cover
+    discord.VoiceClient.warn_nacl = False
+
 
 class SpellBot(AutoShardedBot):
     def __init__(
@@ -63,11 +66,10 @@ class SpellBot(AutoShardedBot):
             await initialize_connection("spellbot-bot")
 
         # register persistent views
-        from .views import PendingGameView, SetupView, StartedGameView
+        from .views import GameView, SetupView
 
-        self.add_view(PendingGameView(self))
+        self.add_view(GameView(self))
         self.add_view(SetupView(self))
-        self.add_view(StartedGameView(self))
 
         # load all cog extensions and application commands
         from .utils import load_extensions
@@ -83,22 +85,20 @@ class SpellBot(AutoShardedBot):
 
     @tracer.wrap()
     async def create_game_link(self, game: GameDict) -> GameLinkDetails:
-        if span := tracer.current_span():
-            span.set_tag("link_service", GameService(game["service"]).name)
-
         if self.mock_games:
             return GameLinkDetails(f"http://exmaple.com/game/{uuid4()}")
         service = game.get("service")
-        if service == GameService.SPELLTABLE.value:
-            if settings.ENABLE_SPELLTABLE:
-                link = await generate_spelltable_link(game)
+        if span := tracer.current_span():
+            span.set_tag("link_service", GameService(service).name)
+        match service:
+            case GameService.SPELLTABLE.value:
+                link = await spelltable.generate_link(game)
                 return GameLinkDetails(link)
-            # fallback to tablestream if spelltable is disabled
-            service = GameService.TABLE_STREAM.value
-        if service == GameService.TABLE_STREAM.value:
-            details = await generate_tablestream_link(game)
-            return GameLinkDetails(*details)
-        return GameLinkDetails()
+            case GameService.TABLE_STREAM.value:
+                details = await tablestream.generate_link(game)
+                return GameLinkDetails(*details)
+            case _:
+                return GameLinkDetails()
 
     @tracer.wrap(name="interaction", resource="on_message")
     async def on_message(
@@ -160,21 +160,19 @@ class SpellBot(AutoShardedBot):
 
     @tracer.wrap()
     async def handle_verification(self, message: discord.Message) -> None:
+        services = ServicesRegistry()
         message_author_xid = message.author.id
         verified: bool | None = None
-        guilds = GuildsService()
         assert message.guild is not None
-        await guilds.upsert(message.guild)
-        channels = ChannelsService()
-        channel_data = await channels.upsert(message.channel)
+        await services.guilds.upsert(message.guild)
+        channel_data = await services.channels.upsert(message.channel)
         if channel_data["auto_verify"]:
             verified = True
-        verify = VerifiesService()
         assert message.guild
         guild: discord.Guild = message.guild
-        await verify.upsert(guild.id, message_author_xid, verified)
+        await services.verifies.upsert(guild.id, message_author_xid, verified)
         if not user_can_moderate(message.author, guild, message.channel):
-            user_is_verified = await verify.is_verified()
+            user_is_verified = await services.verifies.is_verified()
             if user_is_verified and channel_data["unverified_only"]:
                 await safe_delete_message(message)
             if not user_is_verified and channel_data["verified_only"]:
@@ -182,14 +180,14 @@ class SpellBot(AutoShardedBot):
 
     @tracer.wrap()
     async def handle_message_deleted(self, message: discord.Message) -> None:
-        games = GamesService()
-        data = await games.select_by_message_xid(message.id)
+        services = ServicesRegistry()
+        data = await services.games.select_by_message_xid(message.id)
         if not data:
             return
         game_id = data["id"]
         logger.info("Game %s was deleted manually.", game_id)
         if not data["started_at"]:  # someone deleted a pending game
-            await games.delete_games([game_id])
+            await services.games.delete_games([game_id])
 
 
 def build_bot(
