@@ -9,10 +9,12 @@ from typing import TYPE_CHECKING, Any, cast
 import discord
 from aiohttp.client_exceptions import ClientOSError
 from ddtrace.trace import tracer
-from discord.errors import DiscordException
+from discord.errors import DiscordException, NotFound
 from discord.utils import MISSING
+from redis import asyncio as aioredis
 
 from .metrics import add_span_error
+from .settings import settings
 from .utils import (
     CANT_SEND_CODE,
     bot_can_delete_channel,
@@ -38,7 +40,43 @@ if TYPE_CHECKING:
     GetChannelReturnType = GuildChannel | Thread | PrivateChannel | None
 
 logger = logging.getLogger(__name__)
-bad_users: set[int] = set()
+BAD_USER_EXPIRATION = 60 * 60 * 24  # 1 day
+
+
+@tracer.wrap()
+async def mark_bad_user(user_xid: int) -> None:
+    if not settings.REDIS_URL:
+        return
+
+    redis = await aioredis.from_url(settings.REDIS_URL)
+    key = f"bad_user:{user_xid}"
+
+    try:
+        redis.set(key, 1, ex=BAD_USER_EXPIRATION)
+    except Exception:
+        logger.warning("redis error bad user cache", exc_info=True)
+
+
+@tracer.wrap()
+async def is_bad_user(user_xid: int | str | None) -> bool:
+    if not settings.REDIS_URL:
+        return False
+    if not user_xid:
+        return False
+    if isinstance(user_xid, str):
+        try:
+            user_xid = int(user_xid)
+        except ValueError:
+            return False
+
+    redis = await aioredis.from_url(settings.REDIS_URL)
+    key = f"bad_user:{user_xid}"
+
+    try:
+        return await redis.exists(key)
+    except Exception:
+        logger.warning("redis error bad user cache", exc_info=True)
+    return False
 
 
 @tracer.wrap()
@@ -62,6 +100,7 @@ async def safe_original_response(
     with suppress(
         DiscordException,
         ClientOSError,
+        NotFound,
         log="could fetch original response for user %(user_xid)s",
         user_xid=interaction.user.id,
     ):
@@ -70,14 +109,18 @@ async def safe_original_response(
 
 
 @tracer.wrap()
-async def safe_defer_interaction(interaction: discord.Interaction) -> None:
+async def safe_defer_interaction(interaction: discord.Interaction) -> bool:
+    rvalue = False
     with suppress(
         DiscordException,
         ClientOSError,
+        NotFound,
         log="could not defer interaction for user %(user_xid)s",
         user_xid=interaction.user.id,
     ):
         await retry(interaction.response.defer)
+        rvalue = True
+    return rvalue
 
 
 @tracer.wrap()
@@ -95,6 +138,7 @@ async def safe_fetch_user(
     with suppress(
         DiscordException,
         ClientOSError,
+        NotFound,
         log="could not fetch user %(user_xid)s",
         user_xid=user_xid,
     ):
@@ -117,6 +161,7 @@ async def safe_fetch_guild(
     with suppress(
         DiscordException,
         ClientOSError,
+        NotFound,
         log="could not fetch guild %(guild_xid)s",
         guild_xid=guild_xid,
     ):
@@ -149,6 +194,7 @@ async def safe_fetch_text_channel(
     with suppress(
         DiscordException,
         ClientOSError,
+        NotFound,
         log="in guild %(guild_xid)s, could not fetch channel %(channel_xid)s",
         guild_xid=guild_xid,
         channel_xid=channel_xid,
@@ -180,6 +226,7 @@ def safe_get_partial_message(
     with suppress(
         DiscordException,
         ClientOSError,
+        NotFound,
         log="in guild %(guild_xid)s, could not get partial message %(message_xid)s",
         guild_xid=guild_xid,
         message_xid=message_xid,
@@ -201,14 +248,11 @@ async def safe_update_embed(
     with suppress(
         DiscordException,
         ClientOSError,
+        NotFound,
         log="could not update embed in message %(message_xid)s",
         message_xid=message.id,
     ):
-        try:
-            updated_message = await retry(lambda: message.edit(*args, **kwargs))
-        except discord.errors.NotFound:
-            guild_xid = message.guild.id if message.guild else None
-            logger.warning("in guild %s, unknown message %s", guild_xid, message.id)
+        updated_message = await retry(lambda: message.edit(*args, **kwargs))
     return updated_message
 
 
@@ -235,6 +279,7 @@ async def safe_delete_message(message: discord.Message | discord.PartialMessage)
     with suppress(
         DiscordException,
         ClientOSError,
+        NotFound,
         log="could not delete message %(message_xid)s",
         message_xid=message.id,
     ):
@@ -259,6 +304,7 @@ async def safe_update_embed_origin(
     with suppress(
         DiscordException,
         ClientOSError,
+        NotFound,
         log="could not update origin embed in message %(message_xid)s",
         message_xid=interaction.message.id,
     ):
@@ -287,6 +333,7 @@ async def safe_create_category_channel(
     with suppress(
         DiscordException,
         ClientOSError,
+        NotFound,
         log="in guild %(guild_xid)s, could not create category channel",
         guild_xid=guild_xid,
     ):
@@ -314,6 +361,7 @@ async def safe_create_voice_channel(
     with suppress(
         DiscordException,
         ClientOSError,
+        NotFound,
         log="in guild %(guild_xid)s, could not create voice channel",
         guild_xid=guild_xid,
     ):
@@ -409,11 +457,8 @@ async def safe_delete_channel(
         guild_xid=guild_xid,
         channel_xid=channel_xid,
     ):
-        try:
-            await retry(channel.delete)  # type: ignore - this is asserted above
-            success = True
-        except discord.errors.NotFound:
-            logger.warning("in guild  %s, unknown channel %s", guild_xid, channel_xid)
+        await retry(channel.delete)  # type: ignore - this is asserted above
+        success = True
     return success
 
 
@@ -435,6 +480,7 @@ async def safe_send_channel(
     with suppress(
         DiscordException,
         ClientOSError,
+        NotFound,
         log="in guild %(guild_xid)s, could not send message to channel %(channel_xid)s",
         guild_xid=interaction.guild_id,
         channel_xid=interaction.channel_id,
@@ -467,6 +513,7 @@ async def safe_followup_channel(
     with suppress(
         DiscordException,
         ClientOSError,
+        NotFound,
         log="in guild %(guild_xid)s, could not send message to channel %(channel_xid)s",
         guild_xid=interaction.guild_id,
         channel_xid=interaction.channel_id,
@@ -498,6 +545,7 @@ async def safe_channel_reply(
     with suppress(
         DiscordException,
         ClientOSError,
+        NotFound,
         log="in guild %(guild_xid)s, could not reply to channel %(channel_xid)s",
         guild_xid=guild_xid,
         channel_xid=channel_xid,
@@ -521,6 +569,7 @@ async def safe_create_channel_invite(
     with suppress(
         DiscordException,
         ClientOSError,
+        NotFound,
         log="in guild %(guild_xid)s, could not create invite to channel %(channel_xid)s",
         guild_xid=guild_xid,
         channel_xid=channel_xid,
@@ -554,7 +603,7 @@ async def safe_send_user(
     if span := tracer.current_span():  # pragma: no cover
         span.set_tags({"user_xid": str(user_xid)})
 
-    if user_xid in bad_users:
+    if await is_bad_user(user_xid):
         return log_warning("not sending to bad user %(user)s %(xid)s", user=user, xid=user_xid)
 
     if not hasattr(user, "send"):
@@ -579,7 +628,7 @@ async def safe_send_user(
             # It's not clear what can be done to avoid this, but we can maybe mitigate
             # by flagging the user until the next time we restart.
             if user_xid is not None:
-                bad_users.add(user_xid)
+                await mark_bad_user(user_xid)
             return log_info(
                 "not allowed to send message to %(user)s %(xid)s",
                 user=user,
