@@ -8,11 +8,20 @@ from sqlalchemy.dialects.postgresql import insert
 from sqlalchemy.sql.expression import update
 
 from spellbot.database import DatabaseSession
+from spellbot.environment import running_in_pytest
 from spellbot.models import Channel, ChannelDict
 
 if TYPE_CHECKING:
     from discord.abc import MessageableChannel
 
+channel_cache: dict[int, str] = {}
+
+
+def is_cached(xid: int, name: str) -> bool:  # pragma: no cover
+    if running_in_pytest():
+        return False
+    return bool((cached_name := channel_cache.get(xid)) and cached_name == name)
+
 
 class ChannelsService:
     @sync_to_async()
@@ -21,23 +30,26 @@ class ChannelsService:
         name_max_len = Channel.name.property.columns[0].type.length  # type: ignore
         raw_name = getattr(channel, "name", "")
         name = raw_name[:name_max_len]
-        values = {
-            "xid": channel.id,
-            "guild_xid": channel.guild.id,
-            "name": name,
-            "updated_at": datetime.now(tz=UTC),
-        }
-        upsert = insert(Channel).values(**values)
-        upsert = upsert.on_conflict_do_update(
-            index_elements=[Channel.xid],
-            index_where=Channel.xid == values["xid"],
-            set_={
-                "name": upsert.excluded.name,
-                "updated_at": upsert.excluded.updated_at,
-            },
-        )
-        DatabaseSession.execute(upsert, values)
-        DatabaseSession.commit()
+        if not is_cached(channel.id, name):
+            values = {
+                "xid": channel.id,
+                "guild_xid": channel.guild.id,
+                "name": name,
+                "updated_at": datetime.now(tz=UTC),
+            }
+            upsert = insert(Channel).values(**values)
+            upsert = upsert.on_conflict_do_update(
+                index_elements=[Channel.xid],
+                index_where=Channel.xid == values["xid"],
+                set_={
+                    "name": upsert.excluded.name,
+                    "updated_at": upsert.excluded.updated_at,
+                },
+                where=upsert.excluded.name != Channel.name,
+            )
+            DatabaseSession.execute(upsert, values)
+            DatabaseSession.commit()
+            channel_cache[channel.id] = name
 
         db_channel = DatabaseSession.query(Channel).filter(Channel.xid == channel.id).one()
         return db_channel.to_dict()
@@ -188,18 +200,6 @@ class ChannelsService:
         DatabaseSession.commit()
         return value
 
-    @sync_to_async()
-    def set_show_points(self, xid: int, value: bool) -> bool:
-        query = (
-            update(Channel)  # type: ignore
-            .where(Channel.xid == xid)
-            .values(show_points=value)
-            .execution_options(synchronize_session=False)
-        )
-        DatabaseSession.execute(query)
-        DatabaseSession.commit()
-        return value
-
     @sync_to_async()
     def set_blind_games(self, xid: int, value: bool) -> bool:
         query = (
@@ -212,19 +212,6 @@ class ChannelsService:
         DatabaseSession.commit()
         return value
 
-    # TODO: Refactor how confirmation/points/ELO works.
-    # @sync_to_async()
-    # def set_require_confirmation(self, xid: int, value: bool) -> bool:
-    #     query = (
-    #         update(Channel)
-    #         .where(Channel.xid == xid)
-    #         .values(require_confirmation=value)
-    #         .execution_options(synchronize_session=False)
-    #     )
-    #     DatabaseSession.execute(query)
-    #     DatabaseSession.commit()
-    #     return value
-
     @sync_to_async()
     def set_voice_invite(self, xid: int, value: bool) -> bool:
         query = (
