@@ -22,7 +22,7 @@ USER_RECORDS_SQL = r"""
             games.updated_at,
             games.channel_xid,
             posts.message_xid,
-            games.spelltable_link,
+            games.game_link,
             games.format
         FROM games
         JOIN plays ON plays.game_id = games.id
@@ -41,16 +41,14 @@ USER_RECORDS_SQL = r"""
         game_plays.updated_at,
         game_plays.channel_xid,
         game_plays.message_xid,
-        game_plays.spelltable_link,
+        game_plays.game_link,
         game_plays.format,
         channels.name,
         STRING_AGG(
             CONCAT(
                 REPLACE(REPLACE(users.name, ':', ''), '@', ''),
                 ':',
-                users.xid,
-                ':',
-                COALESCE(plays.points, 0)::text
+                users.xid
             ),
             '@'
             ORDER BY users.xid
@@ -64,7 +62,7 @@ USER_RECORDS_SQL = r"""
         game_plays.updated_at,
         game_plays.channel_xid,
         game_plays.message_xid,
-        game_plays.spelltable_link,
+        game_plays.game_link,
         game_plays.format,
         channels.name
     ORDER BY game_plays.updated_at DESC
@@ -76,15 +74,13 @@ CHANNEL_RECORDS_SQL = r"""
         games.id,
         games.updated_at,
         posts.message_xid,
-        games.spelltable_link,
+        games.game_link,
         games.format,
         STRING_AGG(
             CONCAT(
                 REPLACE(REPLACE(users.name, ':', ''), '@', ''),
                 ':',
-                users.xid,
-                ':',
-                COALESCE(plays.points, 0)::text
+                users.xid
             ),
             '@'
             ORDER BY users.xid
@@ -102,7 +98,7 @@ CHANNEL_RECORDS_SQL = r"""
         games.id,
         games.updated_at,
         posts.message_xid,
-        games.spelltable_link,
+        games.game_link,
         games.format
     ORDER BY games.updated_at DESC
     OFFSET :offset
@@ -115,8 +111,8 @@ def make_scores(data: str) -> dict[str, Any]:
     scores = {}
     records = data.split("@")
     for record in records:
-        name, xid, points = record.split(":")
-        scores[name] = (xid, points)
+        name, xid = record.split(":")
+        scores[name] = (xid,)
     return scores
 
 
@@ -136,7 +132,6 @@ def decomposed(combined_data: list[dict[str, Any]]) -> list[dict[str, Any]]:
                 "channel_name": data["channel_name"],
                 "user_name": name,
                 "user_xid": score_data[0],
-                "user_points": score_data[1],
             }
             decomposed_data.append(decomposed_datum)
     return decomposed_data
