@@ -6,12 +6,13 @@ from os import getenv, getpid
 
 from dotenv import load_dotenv
 
-from ..logs import configure_logging
+from spellbot.logs import configure_logging
 
 configure_logging(getenv("LOG_LEVEL") or "INFO")
 
-from ..database import initialize_connection  # noqa: E402
-from ..environment import running_in_pytest  # noqa: E402
+from spellbot.database import initialize_connection  # noqa: E402
+from spellbot.environment import running_in_pytest  # noqa: E402
+
 from . import build_web_app  # noqa: E402
 
 if not running_in_pytest():  # pragma: no cover
