@@ -7,9 +7,8 @@ from unittest.mock import ANY, MagicMock
 import discord
 import pytest
 
-from spellbot.database import DatabaseSession
 from spellbot.enums import GameBracket, GameService
-from spellbot.models import Game, GameStatus, Play
+from spellbot.models import Game, GameStatus
 from spellbot.operations import VoiceChannelSuggestion
 
 if TYPE_CHECKING:
@@ -41,11 +40,8 @@ class TestModelGame:
             "format": game.format,
             "bracket": game.bracket,
             "service": game.service,
-            "spelltable_link": game.spelltable_link,
+            "game_link": game.game_link,
             "jump_links": game.jump_links,
-            "spectate_link": game.spectate_link,
-            "confirmed": game.confirmed,
-            "requires_confirmation": game.requires_confirmation,
             "password": game.password,
             "rules": game.rules,
             "blind": game.blind,
@@ -108,7 +104,7 @@ class TestModelGame:
 
         expected_fields = [
             {"inline": True, "name": "Format", "value": "Commander"},
-            {"inline": True, "name": "Bracket", "value": GameBracket.BRACKET_2.title},
+            {"inline": True, "name": "Bracket", "value": "✦ 2: Core"},
             {"inline": True, "name": "Updated at", "value": "<t:1635638400>"},
         ]
         if service != GameService.SPELLTABLE:
@@ -289,7 +285,7 @@ class TestModelGame:
             "flags": 0,
         }
 
-    def test_game_embed_started_with_spelltable_link(
+    def test_game_embed_started_with_game_link(
         self,
         settings: Settings,
         factories: Factories,
@@ -300,7 +296,7 @@ class TestModelGame:
             seats=2,
             status=GameStatus.STARTED.value,
             started_at=datetime(2021, 10, 31, tzinfo=UTC),
-            spelltable_link="https://spelltable/link",
+            game_link="https://spelltable/link",
             guild=guild,
             channel=channel,
         )
@@ -333,7 +329,7 @@ class TestModelGame:
             "color": settings.STARTED_EMBED_COLOR,
             "description": (
                 "# [Join your SpellTable game now!]"
-                f"({game.spelltable_link})\n"
+                f"({game.game_link})\n"
                 "\n"
                 "You can also [jump to the original game post]"
                 "(https://discordapp.com/channels/"
@@ -369,7 +365,7 @@ class TestModelGame:
             seats=2,
             status=GameStatus.STARTED.value,
             started_at=datetime(2021, 10, 31, tzinfo=UTC),
-            spelltable_link=None,
+            game_link=None,
             guild=guild,
             channel=channel,
             service=GameService.NOT_ANY.value,
@@ -440,7 +436,7 @@ class TestModelGame:
             seats=2,
             status=GameStatus.STARTED.value,
             started_at=datetime(2021, 10, 31, tzinfo=UTC),
-            spelltable_link=None,
+            game_link=None,
             guild=guild,
             channel=channel,
             service=GameService.MTG_ARENA.value,
@@ -502,7 +498,7 @@ class TestModelGame:
 
     def test_game_with_guild_notice(self, settings: Settings, factories: Factories) -> None:
         guild = factories.guild.create(motd=None, notice="this is a notice")
-        channel = factories.channel.create(guild=guild, show_points=True, motd=None)
+        channel = factories.channel.create(guild=guild, motd=None)
         game = factories.game.create(
             seats=2,
             status=GameStatus.STARTED.value,
@@ -513,72 +509,10 @@ class TestModelGame:
         factories.user.create(game=game)
         factories.user.create(game=game)
         assert game.to_embed().to_dict()["description"] == (
-            "this is a notice\n\n"
-            "Please check your Direct Messages for your game details.\n\n"
-            "When your game is over use the drop down to report your points."
+            "this is a notice\n\nPlease check your Direct Messages for your game details."
         )
 
-    def test_game_embed_started_with_points(
-        self,
-        settings: Settings,
-        factories: Factories,
-    ) -> None:
-        guild = factories.guild.create(motd=None)
-        channel = factories.channel.create(guild=guild, show_points=True, motd=None)
-        game = factories.game.create(
-            seats=2,
-            status=GameStatus.STARTED.value,
-            started_at=datetime(2021, 10, 31, tzinfo=UTC),
-            guild=guild,
-            channel=channel,
-        )
-        player1 = factories.user.create(game=game)
-        player2 = factories.user.create(game=game)
-        DatabaseSession.query(Play).filter(
-            Play.game_id == game.id,
-            Play.user_xid == player1.xid,
-        ).update(
-            {
-                Play.points: 5,  # type: ignore
-            },
-        )
-        DatabaseSession.query(Play).filter(
-            Play.game_id == game.id,
-            Play.user_xid == player2.xid,
-        ).update(
-            {
-                Play.points: 1,  # type: ignore
-            },
-        )
-
-        assert game.to_embed().to_dict() == {
-            "color": settings.STARTED_EMBED_COLOR,
-            "description": (
-                "Please check your Direct Messages for your game details.\n"
-                "\n"
-                "When your game is over use the drop down to report your points."
-            ),
-            "fields": [
-                {
-                    "inline": False,
-                    "name": "Players",
-                    "value": (
-                        f"• <@{player1.xid}> ({player1.name})\n**ﾠ⮑ 5 points**\n"
-                        f"• <@{player2.xid}> ({player2.name})\n**ﾠ⮑ 1 point**"
-                    ),
-                },
-                {"inline": True, "name": "Format", "value": "Commander"},
-                {"inline": True, "name": "Started at", "value": "<t:1635638400>"},
-                {"inline": False, "name": "Support SpellBot", "value": ANY},
-            ],
-            "footer": {"text": f"SpellBot Game ID: #SB{game.id}"},
-            "thumbnail": {"url": settings.THUMB_URL},
-            "title": "**Your game is ready!**",
-            "type": "rich",
-            "flags": 0,
-        }
-
-    def test_game_embed_started_without_spelltable_link(
+    def test_game_embed_started_without_game_link(
         self,
         settings: Settings,
         factories: Factories,
@@ -620,7 +554,7 @@ class TestModelGame:
         assert game.to_embed(dm=True).to_dict() == {
             "color": settings.STARTED_EMBED_COLOR,
             "description": (
-                "Sorry but SpellBot was unable to create a SpellTable link for "
+                "Sorry but SpellBot was unable to create a link for "
                 "this game. Please go to [SpellTable]"
                 "(https://spelltable.wizards.com/) to create one.\n"
                 "\n"
@@ -692,7 +626,7 @@ class TestModelGame:
         assert game.to_embed(dm=True).to_dict() == {
             "color": settings.STARTED_EMBED_COLOR,
             "description": (
-                "Sorry but SpellBot was unable to create a Table Stream link for "
+                "Sorry but SpellBot was unable to create a link for "
                 "this game. Please go to [Table Stream]"
                 "(https://table-stream.com/) to create one.\n"
                 "\n"
@@ -733,7 +667,7 @@ class TestModelGame:
             seats=2,
             status=GameStatus.STARTED.value,
             started_at=datetime(2021, 10, 31, tzinfo=UTC),
-            spelltable_link="https://spelltable/link",
+            game_link="https://spelltable/link",
             voice_xid=501,
             guild=guild,
             channel=channel,
@@ -767,7 +701,7 @@ class TestModelGame:
             "color": settings.STARTED_EMBED_COLOR,
             "description": (
                 "# [Join your SpellTable game now!]"
-                f"({game.spelltable_link})\n"
+                f"({game.game_link})\n"
                 "\n"
                 f"## Join your voice chat now: <#{game.voice_xid}>\n"
                 "\n"
@@ -805,7 +739,7 @@ class TestModelGame:
             seats=2,
             status=GameStatus.STARTED.value,
             started_at=datetime(2021, 10, 31, tzinfo=UTC),
-            spelltable_link="https://spelltable/link",
+            game_link="https://spelltable/link",
             voice_xid=501,
             voice_invite_link="https://voice/invite",
             guild=guild,
@@ -840,7 +774,7 @@ class TestModelGame:
             "color": settings.STARTED_EMBED_COLOR,
             "description": (
                 "# [Join your SpellTable game now!]"
-                f"({game.spelltable_link})\n"
+                f"({game.game_link})\n"
                 "\n"
                 f"## Join your voice chat now: <#{game.voice_xid}>\n"
                 f"Or use this voice channel invite: {game.voice_invite_link}\n"
@@ -875,7 +809,7 @@ class TestModelGame:
             seats=2,
             status=GameStatus.STARTED.value,
             started_at=datetime(2021, 10, 31, tzinfo=UTC),
-            spelltable_link="https://spelltable/link",
+            game_link="https://spelltable/link",
             guild=guild,
             channel=channel,
         )
@@ -912,7 +846,7 @@ class TestModelGame:
             "color": settings.STARTED_EMBED_COLOR,
             "description": (
                 "# [Join your SpellTable game now!]"
-                f"({game.spelltable_link})\n"
+                f"({game.game_link})\n"
                 "\n"
                 "You can also [jump to the original game post]"
                 "(https://discordapp.com/channels/"
@@ -939,70 +873,6 @@ class TestModelGame:
             "flags": 0,
         }
 
-    def test_game_embed_started_with_win_loss(
-        self,
-        settings: Settings,
-        factories: Factories,
-    ) -> None:
-        guild = factories.guild.create(motd=None)
-        channel = factories.channel.create(
-            guild=guild,
-            show_points=True,
-            require_confirmation=True,
-            motd=None,
-        )
-        game = factories.game.create(
-            seats=2,
-            status=GameStatus.STARTED.value,
-            started_at=datetime(2021, 10, 31, tzinfo=UTC),
-            guild=guild,
-            channel=channel,
-            requires_confirmation=True,
-        )
-        player1 = factories.user.create(game=game, xid=1)
-        player2 = factories.user.create(game=game, xid=2)
-        player3 = factories.user.create(game=game, xid=3)
-        DatabaseSession.query(Play).filter(
-            Play.game_id == game.id,
-            Play.user_xid == player1.xid,
-        ).update({Play.points: 3})  # type: ignore
-        DatabaseSession.query(Play).filter(
-            Play.game_id == game.id,
-            Play.user_xid == player2.xid,
-        ).update({Play.points: 1})  # type: ignore
-        DatabaseSession.query(Play).filter(
-            Play.game_id == game.id,
-            Play.user_xid == player3.xid,
-        ).update({Play.points: 0})  # type: ignore
-
-        assert game.to_embed().to_dict() == {
-            "color": settings.STARTED_EMBED_COLOR,
-            "description": (
-                "Please check your Direct Messages for your game details.\n"
-                "\n"
-                "When your game is over use the drop down to report your points."
-            ),
-            "fields": [
-                {
-                    "inline": False,
-                    "name": "Players",
-                    "value": (
-                        f"• <@{player1.xid}> ({player1.name})\n**ﾠ⮑ ❌ WIN**\n"
-                        f"• <@{player2.xid}> ({player2.name})\n**ﾠ⮑ ❌ TIE**\n"
-                        f"• <@{player3.xid}> ({player3.name})\n**ﾠ⮑ ❌ LOSS**"
-                    ),
-                },
-                {"inline": True, "name": "Format", "value": "Commander"},
-                {"inline": True, "name": "Started at", "value": "<t:1635638400>"},
-                {"inline": False, "name": "Support SpellBot", "value": ANY},
-            ],
-            "footer": {"text": f"SpellBot Game ID: #SB{game.id}"},
-            "thumbnail": {"url": settings.THUMB_URL},
-            "title": "**Your game is ready!**",
-            "type": "rich",
-            "flags": 0,
-        }
-
     def test_game_embed_started_with_suggested_voice_channel(
         self,
         settings: Settings,
@@ -1014,7 +884,7 @@ class TestModelGame:
             seats=2,
             status=GameStatus.STARTED.value,
             started_at=datetime(2021, 10, 31, tzinfo=UTC),
-            spelltable_link="https://spelltable/link",
+            game_link="https://spelltable/link",
             guild=guild,
             channel=channel,
         )
@@ -1060,7 +930,7 @@ class TestModelGame:
             "color": settings.STARTED_EMBED_COLOR,
             "description": (
                 "# [Join your SpellTable game now!]"
-                f"({game.spelltable_link})\n"
+                f"({game.game_link})\n"
                 "\n"
                 f"## Please consider using this available voice channel: <#{dc.id}>.\n"
                 "**˙ॱ⋅.˳.⋅ॱ˙ॱ⋅.˳.⋅ॱ˙ॱ⋅.˳.⋅ॱ˙ॱ⋅.˳.⋅ॱ˙ॱ⋅.˳.⋅ॱ˙ॱ⋅.˳.⋅ॱ˙ॱ⋅.˳.⋅ॱ˙ॱ⋅.˳.⋅ॱ˙ॱ⋅.˳.⋅ॱ˙**\n"
