@@ -34,34 +34,30 @@ pytestmark = pytest.mark.use_db
 @pytest.mark.asyncio
 class TestSpellBot(BaseMixin):
     @pytest.mark.parametrize(
-        ("mock_games", "game", "factory", "interactive"),
+        ("mock_games", "game", "factory"),
         [
             pytest.param(
                 True,
                 {},
                 None,
-                None,
                 id="mock-games",
             ),
             pytest.param(
                 False,
                 {"service": GameService.SPELLTABLE.value},
-                "generate_spelltable_link",
-                False,
+                "spelltable.generate_link",
                 id="spellbot",
             ),
             pytest.param(
                 False,
                 {"service": GameService.TABLE_STREAM.value},
-                "generate_tablestream_link",
-                None,
+                "tablestream.generate_link",
                 id="tablestream",
             ),
             pytest.param(
                 False,
                 {"service": GameService.NOT_ANY.value},
                 None,
-                None,
                 id="no-service",
             ),
         ],
@@ -72,7 +68,6 @@ class TestSpellBot(BaseMixin):
         mock_games: bool,
         game: GameDict,
         factory: str | None,
-        interactive: bool | None,
         mocker: MockerFixture,
     ) -> None:
         bot.mock_games = mock_games
@@ -80,8 +75,7 @@ class TestSpellBot(BaseMixin):
             mock = mocker.patch(f"spellbot.client.{factory}", AsyncMock())
         response = await bot.create_game_link(game)
         if factory:
-            kwargs = {"interactive": interactive} if interactive is not None else {}
-            mock.assert_called_once_with(game, **kwargs)
+            mock.assert_called_once_with(game)
         if mock_games:
             assert response.link is not None
             assert response.link.startswith("http://exmaple.com/game/")
@@ -135,7 +129,7 @@ class TestSpellBot(BaseMixin):
         response: str,
     ) -> None:
         await handle_interaction_errors(interaction, error)
-        interaction.user.send.assert_called_once_with(response)
+        interaction.user.send.assert_called_once_with(response)  # type: ignore
 
     async def test_handle_interaction_errors_unhandled_exception(
         self,
@@ -195,8 +189,8 @@ class TestSpellBot(BaseMixin):
         dpy_message.flags.value = 16
         await bot.on_message(dpy_message)
         super_on_message_mock.assert_not_called()
-        bot.handle_verification.assert_called_once_with(dpy_message)
-        dpy_message.reply.assert_not_called()
+        bot.handle_verification.assert_called_once_with(dpy_message)  # type: ignore
+        dpy_message.reply.assert_not_called()  # type: ignore
 
     async def test_on_message_delete_happy_path(
         self,
@@ -207,7 +201,7 @@ class TestSpellBot(BaseMixin):
         mock_handle_message_deleted = AsyncMock()
         monkeypatch.setattr(bot, "handle_message_deleted", mock_handle_message_deleted)
         await bot.on_message_delete(dpy_message)
-        bot.handle_message_deleted.assert_called_once_with(dpy_message)
+        bot.handle_message_deleted.assert_called_once_with(dpy_message)  # type: ignore
 
     async def test_on_message_delete_message_without_id(
         self,
@@ -219,7 +213,7 @@ class TestSpellBot(BaseMixin):
         mock_handle_message_deleted = AsyncMock()
         monkeypatch.setattr(bot, "handle_message_deleted", mock_handle_message_deleted)
         await bot.on_message_delete(dpy_message)
-        bot.handle_message_deleted.assert_not_called()
+        bot.handle_message_deleted.assert_not_called()  # type: ignore
 
     async def test_on_command_error_command_not_found(
         self,
@@ -335,7 +329,7 @@ class TestSpellBotHandleVerification(BaseMixin):
 
         await self.bot.on_message(message)
 
-        self.bot.handle_verification.assert_not_called()
+        self.bot.handle_verification.assert_not_called()  # type: ignore
 
     async def test_without_auto_verify(self, dpy_message: discord.Message) -> None:
         assert dpy_message.guild
@@ -386,7 +380,7 @@ class TestSpellBotHandleVerification(BaseMixin):
 
         await self.bot.handle_verification(dpy_message)
 
-        dpy_message.delete.assert_called_once()
+        dpy_message.delete.assert_called_once()  # type: ignore
 
     async def test_verified_only_when_verified(self, dpy_message: discord.Message) -> None:
         assert dpy_message.guild
@@ -406,7 +400,7 @@ class TestSpellBotHandleVerification(BaseMixin):
 
         await self.bot.handle_verification(dpy_message)
 
-        dpy_message.delete.assert_not_called()
+        dpy_message.delete.assert_not_called()  # type: ignore
 
     async def test_unverified_only_when_unverified(self, dpy_message: discord.Message) -> None:
         assert dpy_message.guild
@@ -420,7 +414,7 @@ class TestSpellBotHandleVerification(BaseMixin):
 
         await self.bot.handle_verification(dpy_message)
 
-        dpy_message.delete.assert_not_called()
+        dpy_message.delete.assert_not_called()  # type: ignore
 
     async def test_unverified_only_when_verified(self, dpy_message: discord.Message) -> None:
         assert dpy_message.guild
@@ -440,7 +434,7 @@ class TestSpellBotHandleVerification(BaseMixin):
 
         await self.bot.handle_verification(dpy_message)
 
-        dpy_message.delete.assert_called_once()
+        dpy_message.delete.assert_called_once()  # type: ignore
 
     async def test_message_from_mod_role(
         self,
@@ -461,7 +455,7 @@ class TestSpellBotHandleVerification(BaseMixin):
 
         await self.bot.handle_verification(dpy_message)
 
-        dpy_message.delete.assert_not_called()
+        dpy_message.delete.assert_not_called()  # type: ignore
 
     async def test_message_from_admin_role(
         self,
@@ -482,7 +476,7 @@ class TestSpellBotHandleVerification(BaseMixin):
 
         await self.bot.handle_verification(dpy_message)
 
-        dpy_message.delete.assert_not_called()
+        dpy_message.delete.assert_not_called()  # type: ignore
 
     async def test_message_from_owner(
         self,
@@ -501,7 +495,7 @@ class TestSpellBotHandleVerification(BaseMixin):
 
         await self.bot.handle_verification(dpy_message)
 
-        dpy_message.delete.assert_not_called()
+        dpy_message.delete.assert_not_called()  # type: ignore
 
     async def test_message_from_administrator(self, dpy_message: discord.Message) -> None:
         assert dpy_message.guild
@@ -517,4 +511,4 @@ class TestSpellBotHandleVerification(BaseMixin):
 
         await self.bot.handle_verification(dpy_message)
 
-        dpy_message.delete.assert_not_called()
+        dpy_message.delete.assert_not_called()  # type: ignore
